import requests
import json
from janda.utils.parser import *

BASE_URL = Api()

class Hentai2read(object):
    """
    A class used to represent a doujin.

    """

    def __init__(self, api_key: str = ''):
        """Initializes the Pururin.

        Parameters
        ----------
        api_key : str
            scathach.dev API key (optional)
        """
        if api_key == '':
            self.api_key = None
        else:
            self.api_key = api_key
        self.specs = {'api_key': self.api_key}

    async def get(self, path: str, chapter: int = 1):
        """Get doujin API from Id

        path: https://hentai2read.com/a_story_of_tomoe_gozen_being_punished_by_a_shota/1/

        Parameters
        ----------
        path : str
            The path url

        chapter : int
            The chapter number. Default is 1

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The book object that represents the specific id response.
        """

        ## if path contains '/' then remove it
        if '/' in path:
            path = path.replace('/', '')
        
        self.specs['u'] = path + '/' + str(chapter)


        try:
            path = str(path)
        except ValueError:
            raise ValueError('Path must be a str')

        data = requests.get(BASE_URL.hentai2read, params=self.specs)

        self.final = json.loads(better_object(data.json()), encoding="utf-8")
   
        if self.final["title"] is '':
            raise ValueError('No results. Make sure you spelled everything right.')

        return better_object(self.final)

    async def search(self, query: str):
        """Search for doujin based on the latest 

        path: https://hentai2read.com/hentai-list/search/alter

        Parameters
        ----------
        query : str
            The query to search for.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The list object that represents the doujin response.
        """

        self.specs['query'] = query

        query = auto_space(query)

        if query is '':
            raise ValueError('Query must be given')
        data = requests.get(BASE_URL.hentai2read + 'args.php', params=self.specs)

        # if data.json() length is 0, then throw error
        if len(data.json()) == 0:
            raise ValueError('No results found')

        return better_object(data.json())

    async def get_random(self):
        """Gets random doujin on Hentai2read

        Returns
        -------
        dict
            The book object that represents the doujin response.
        """
        data = requests.get(BASE_URL.hentai2read + 'random' + '/', params=self.specs)

        return better_object(data.json())




import requests
import json
from janda.utils.parser import *

BASE_URL = Api()

class Hentaifox(object):
    """
    A class used to represent a doujin.

    """

    def __init__(self, api_key: str = ''):
        """Initializes the Hentaifox.

        Parameters
        ----------
        api_key : str
            scathach.dev API key (optional)
        """
        if api_key == '':
            self.api_key = None
        else:
            self.api_key = api_key
        self.specs = {'api_key': self.api_key}

    async def get(self, book: int):
        """Get doujin API from Id

        path: https://hentaifox.com/gallery/88027/

        Parameters
        ----------
        book : int
            The id number of the doujin.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The book object that represents the specific id response.
        """

        self.specs['g'] = book

        # handle if book not int, then throw error
        try:
            book = int(book)
        except ValueError:
            raise ValueError('Book must be an int')

        data = requests.get(BASE_URL.hentaifox, params=self.specs)
        if data.json()['type'] is None:
            raise ValueError('No results found')

        self.final = json.loads(better_object(data.json()), encoding="utf-8")

        return better_object(self.final)

    async def search_by_latest(self, query: str, page: int = 1):
        """Search for doujin based on the latest 

        path: https://hentaifox.com/search/?q=alter&sort=latest

        Parameters
        ----------
        query : str
            The query to search for.
        
        page : int
            The page number to search

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The list object that represents the doujin response.
        """

        self.specs['query'] = query
        self.specs['sort'] = "latest"
        self.specs['page'] = page

        query = auto_space(query)

        if query is '':
            raise ValueError('Query must be given')
        data = requests.get(BASE_URL.hentaifox + 'args.php', params=self.specs)

        # if data.json() length is 0, then throw error
        if len(data.json()) == 0:
            raise ValueError('No results found')

        return better_object(data.json())

    async def search_by_popular(self, query: str, page: int = 1):
        """Search for doujin based on the latest 

        path: https://hentaifox.com/search/?q=alter&sort=popular

        Parameters
        ----------
        query : str
            The query to search for.
        
        page : int
            The page number to search

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The list object that represents the doujin response.
        """

        self.specs['query'] = query
        self.specs['sort'] = "popular"
        self.specs['page'] = page

        query = auto_space(query)

        if query is '':
            raise ValueError('Query must be given')
        data = requests.get(BASE_URL.hentaifox + 'args.php', params=self.specs)

        # if data.json() length is 0, then throw error
        if len(data.json()) == 0:
            raise ValueError('No results found')

        return better_object(data.json())

    async def get_random(self):
        """Gets random doujin on hentaifox

        Returns
        -------
        dict
            The book object that represents the doujin response.
        """
        data = requests.get(BASE_URL.hentaifox + 'random' + '/', params=self.specs)

        return better_object(data.json())





import asyncio
from janda import Hentaifox

hentaifox = Hentaifox()

async def get():
    data = await hentaifox.get(59026)
    print(data)

async def main():
    await asyncio.gather(get())

asyncio.run(main())



import asyncio
from janda import Nhentai

nhentai = Nhentai()

async def get():
    data = await nhentai.get(255369)
    print(data)

async def main():
    await asyncio.gather(get())

asyncio.run(main())


import json
import requests

with open('base.json', 'r', encoding='utf-8') as f:
    site = json.load(f)
    api_list = []
    for key, value in site.items():
        api_list.append(value['api'])
        ## print(value['api'])
        r = requests.get(value['api'])
        print(value['api'], r.status_code)



import requests
import json
from janda.utils.parser import *

BASE_URL = Api()

class Nhentai(object):    

    def __init__(self, api_key: str = ''):
        """Initializes the client.

        Parameters
        ----------
        api_key : str
            scathach.dev API key for pururin (optional)
        
        Returns
        -------
        None
        """
        if api_key == '':
            self.api_key = None
        else:
            self.api_key = api_key
        self.specs = {'api_key': self.api_key}

    async def get(self, book: int, safe: bool = None):
        """Get doujin API from Id

        Parameters
        ----------
        book : int
            Nmber id of the book

        safe : bool
            If True, janda will throw you error whenever contains minor content, such as loli or shota. Default is False

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
        """

        try:

            if isinstance(book, int):
                book = str(book)

            self.book = str(just_number(book))

        except ValueError:
            raise ValueError('Book must be contain int')

        data = requests.get(F'{BASE_URL.api}/api/gallery/{self.book}')
        if data.status_code == 404:
            raise ValueError('Book not found')

        if data.status_code != 200:
            raise ValueError('Request failed')

        self.tags = preg_match_tags(data.json()['tags'])

        if safe is True:
            if 'lolicon' in self.tags or 'shotacon' in self.tags:
                raise ValueError('Book contains minor content')
        
        return parser(data.json())


    async def search(self, tags: str, page: int = 1, popular: str = 'today'):
        """Search doujin by tags / artis / character / parody or group

        Parameters
        ----------
        tags : str
            Tags to search for.

        page : int
            Page number. Default is 1.

        popular : str
            Popularity type. Default is today.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
        """

        if popular not in ['today', 'all', 'week']:
            raise ValueError('popular must be today, all, or week')

        self.specs['query'] = tags
        self.specs['page'] = page
        self.specs['popular'] = popular

        data = requests.get(
            f'{BASE_URL.api}/api/galleries/search', params=self.specs)

        if data.status_code == 404:
            raise ValueError('No results')

        if data.status_code != 200:
            raise ValueError('Request failed')


        self.raw_object = json.loads(better_object(data.json()), encoding="utf-8")
        self.results = self.raw_object['result']

        self.results_object = []
        for result in self.results:
            self.results_object.append({
                'id': result['id'],
                'title': result['title'],
                'link': f'https://nhentai.net/g/{result["id"]}',
                'upload_date': readable_timestamp(result['upload_date']),
                'num_pages': result['num_pages'],
                'num_favorites': result['num_favorites'],
                'language': get_language_in_tags(result['tags']),
                'tags': preg_match_tags(result['tags'])
            })

        return better_object(self.results_object)


    async def search_related(self, book: int):
        """Get realated book API from book ID or book link

        Parameters
        ----------
        book : int
            Nmber id of the book

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
        """

        try:
            if isinstance(book, int):
                book = str(book)

            self.book = str(just_number(book))

        except ValueError:
            raise ValueError('Book must be an int')

        data = requests.get(F'{BASE_URL.api}/api/gallery/{self.book}/related')

        if data.status_code != 200:
            raise ValueError('Request failed')

        return neat_result(data.json())

    async def get_random(self):
        """Get random doujin
        
        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
        """
        random = requests.get(F'{BASE_URL.api}/random')

        try:
            self.book = str(just_number(random.url))

        except ValueError:
            raise ValueError('Uh oh something wrong here')

        data = requests.get(F'{BASE_URL.api}/api/gallery/{self.book}')
        
        if data.status_code == 404:
            raise ValueError('Error')

        if data.status_code != 200:
            raise ValueError('Request failed')

        return parser(data.json())
        




import asyncio
from janda import Hentai2read

h2r = Hentai2read()

async def get():
    data = await h2r.get("jeanne_alter_wants_to_mana_transfer")
    print(data)

async def main():
    await asyncio.gather(get())

asyncio.run(main())



import asyncio
from janda import Pururin

pururin = Pururin()

async def get():
    data = await pururin.get(47226)
    print(data)

async def main():
    await asyncio.gather(get())

asyncio.run(main())


import requests
import json
from janda.utils.parser import Api

BASE_URL = Api()

class Pururin(object):
    """
    A class used to represent a doujin.

    """
    @staticmethod
    def better_object(parser: dict):
        """Converts the json object to a more readable object.

        Parameters
        ----------
        parser : dict
            The json object.
        """
        return json.dumps(parser, sort_keys=True, indent=4)

    @staticmethod
    def auto_space(string: str):
        """Automatically adds spaces for GET requests

        Parameters
        ----------
        string : str
            The string to be formatted.
        """

        return string.replace(' ', '+')

    def __init__(self, api_key: str = ''):
        """Initializes the Pururin.

        Parameters
        ----------
        api_key : str
            scathach.dev API key (optional)
        """
        if api_key == '':
            self.api_key = None
        else:
            self.api_key = api_key
        self.specs = {'api_key': self.api_key}

    async def get(self, book: int):
        """Get doujin API from Id

        path: https://pururin.to/gallery/61119

        Parameters
        ----------
        book : int
            The id number of the doujin.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The book object that represents the specific id response.
        """

        self.specs['g'] = book

        # handle if book not int, then throw error
        try:
            book = int(book)
        except ValueError:
            raise ValueError('Book must be an int')

        data = requests.get(BASE_URL.pururin, params=self.specs)
        if data.json()['type'] is None:
            raise ValueError('No results found')

        self.final = json.loads(Pururin.better_object(data.json()), encoding="utf-8")

        return Pururin.better_object(self.final)

    async def search_by_newest(self, query: str):
        """Search for doujin based on newest 

        path: https://pururin.to/search/most-popular?q=alter

        Parameters
        ----------
        query : str
            The query to search for.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The list object that represents the doujin response.
        """

        self.specs['query'] = query
        self.specs['sort'] = "newest"
        query = Pururin.auto_space(query)

        if query is '':
            raise ValueError('Query must be given')
        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)

        # if data.json() length is 0, then throw error
        if len(data.json()) == 0:
            raise ValueError('No results found')

        return Pururin.better_object(data.json())

    async def search_by_most_popular(self, query: str):
        """Search doujins by most popular

        path: https://pururin.to/search/most-popular?q=alter

        Parameters
        ----------
        query : str
            The query to search for.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The list object that represents the doujin response.
        """

        self.specs['query'] = query
        self.specs['sort'] = "most-popular"
        query = Pururin.auto_space(query)

        if query is '':
            raise ValueError('Query must be given')
        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)

        # if data.json() length is 0, then throw error
        if len(data.json()) == 0:
            raise ValueError('No results found')

        return Pururin.better_object(data.json())

    async def search_by_highest_rated(self, query: str):
        """Search for doujin based on the highest rated

        path: https://pururin.to/search/highest-rated?q=alter

        Parameters
        ----------
        query : str
            The query to search for.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The list object that represents the doujin response.
        """

        self.specs['query'] = query
        self.specs['sort'] = "highest-rated"
        query = Pururin.auto_space(query)

        if query is '':
            raise ValueError('Query must be given')
        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)

        # if data.json() length is 0, then throw error
        if len(data.json()) == 0:
            raise ValueError('No results found')

        return Pururin.better_object(data.json())

    async def search_by_most_viewed(self, query: str):
        """Search for doujin based on the most viewed

        path: https://pururin.to/search/most-viewed?q=alter

        Parameters
        ----------
        query : str
            The query to search for.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The list object that represents the doujin response.
        """

        self.specs['query'] = query
        self.specs['sort'] = "most-viewed"
        query = Pururin.auto_space(query)

        if query is '':
            raise ValueError('Query must be given')
        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)

        # if data.json() length is 0, then throw error
        if len(data.json()) == 0:
            raise ValueError('No results found')

        return Pururin.better_object(data.json())

    async def search_by_title(self, query: str):
        """Search for doujin based on title

        path: https://pururin.to/search/title?q=alter

        Parameters
        ----------
        query : str
            The query to search for.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The list object that represents the doujin response.
        """

        self.specs['query'] = query
        self.specs['sort'] = "title"
        query = Pururin.auto_space(query)

        if query is '':
            raise ValueError('Query must be given')
        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)

        # if data.json() length is 0, then throw error
        if len(data.json()) == 0:
            raise ValueError('No results found')

        return Pururin.better_object(data.json())

    async def search_by_random(self, query: str):
        """Search for doujin based on random

        path: https://pururin.to/search/random?q=alter

        Parameters
        ----------
        query : str
            The query to search for.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The list object that represents the doujin response.
        """

        self.specs['query'] = query
        self.specs['sort'] = "random"
        query = Pururin.auto_space(query)

        if query is '':
            raise ValueError('Query must be given')
        data = requests.get(BASE_URL.pururin + 'args.php', params=self.specs)

        # if data.json() length is 0, then throw error
        if len(data.json()) == 0:
            raise ValueError('No results found')

        return Pururin.better_object(data.json())

    async def get_random(self):
        """Gets random doujin on pururin

        Returns
        -------
        dict
            The book object that represents the doujin response.
        """
        data = requests.get(BASE_URL.pururin + 'random' + '/', params=self.specs)

        return Pururin.better_object(data.json())

    async def get_random_with_query(self, query: str):
        """Gets doujin on pururin by query

        path: https://pururin.to/search?q=alter

        Parameters
        ----------
        query : str
            The query to search for.

        Raises
        ------
        ValueError
            If the doujin is not found.

        Returns
        -------
        dict
            The book object that represents the doujin response.
        """

        self.specs['p'] = query
        query = Pururin.auto_space(query)
        data = requests.get(BASE_URL.pururin + 'search.php', params=self.specs)

        # if result null, then throw error
        if data.json()['type'] is None:
            raise ValueError('No results found')

        return Pururin.better_object(data.json())
